#!/usr/bin/env python
# -*-coding:utf-8 -*-
"""""" 
"""
@File    :   __init__.py
@Time    :   2022/06/24 09:59:42
@Author  :   Bart Ortiz 
@Version :   0.1.6
@Contact :   bortiz@ugr.es
@License :   CC-BY-SA or GPL3
@Desc    :   Init file for the recorpy package
"""

from recorpy.reorder import ReorderCorr

__version__ = "0.1.7"
